***************************
The sherpa.utils.err module
***************************

.. currentmodule:: sherpa.utils.err

.. automodule:: sherpa.utils.err
                
   .. rubric:: Exceptions
                   
   .. autosummary::
      :toctree: api

      SherpaErr
      ArgumentErr
      ArgumentTypeErr
      ConfidenceErr
      DS9Err
      DataErr
      EstErr
      FitErr
      IOErr
      IdentifierErr
      ImportErr
      InstrumentErr
      ModelErr
      NotImplementedErr
      PSFErr
      ParameterErr
      PlotErr
      SessionErr
      StatErr

Class Inheritance Diagram
=========================

.. inheritance-diagram:: SherpaErr ArgumentErr ArgumentTypeErr ConfidenceErr DS9Err DataErr EstErr FitErr IOErr IdentifierErr ImportErr InstrumentErr ModelErr NotImplementedErr PSFErr ParameterErr PlotErr SessionErr StatErr
   :parts: 1
